.. _demo_videos:

Demo Videos
===========

Quick Introduction to Glue (2 minutes)
--------------------------------------

.. raw:: html

 <center>
 <iframe width="640" height="376" src="https://www.youtube.com/embed/qO3RQiRjWA4?rel=0" frameborder="0" allowfullscreen></iframe>
 </center>

2013 SciPy Conference Talk (20 minutes)
---------------------------------------
.. raw:: html

  <center><iframe width="640" height="390" src="https://www.youtube.com/embed/47LNpvDlKUk" frameborder="0" allowfullscreen></iframe></center>

The Perseus Shell (2 Minutes)
-----------------------------
*Featured in Alyssa Goodman's plenary talk at the 223rd meeting of the American Astronomical Society*

.. raw:: html

 <center>
 <iframe src="https://player.vimeo.com/video/83497221?badge=0"  width="500" height="275" frameborder="0" webkitAllowFullScreen mozallowfullscreen allowFullScreen></iframe>
 </center>

Glue, data cleaning, and civic hacking (5 minutes)
--------------------------------------------------

.. raw:: html

 <center>
 <iframe src="https://player.vimeo.com/video/65789362?badge=0"  width="500" height="275" frameborder="0" webkitAllowFullScreen mozallowfullscreen allowFullScreen></iframe>
 </center>

Glue, FBI Crime Data, and Plotly (5 minutes)
--------------------------------------------

.. raw:: html

 <center>
 <iframe src="https://player.vimeo.com/video/97436621" width="500" height="313" frameborder="0" webkitallowfullscreen mozallowfullscreen allowfullscreen></iframe> <
 </center>

See also the `IPython notebook <https://nbviewer.jupyter.org/github/ChrisBeaumont/crime/blob/master/glue_plotly_fbi.ipynb>`_ that accompanies this video.

Extracting slices from cubes
----------------------------

.. raw:: html

 <center>
 <iframe src="https://player.vimeo.com/video/96815794" width="500" height="333" frameborder="0" webkitallowfullscreen mozallowfullscreen allowfullscreen></iframe>
 </center>